#! /usr/bin/env python
# coding: utf-8
usage = """Usage: ./make_individual_html.py image_sizes descrip

    Examines the descrip file and builds a medium, large and full
    size HTML page for each image, with forward, up, and back links
    on each page.

    image_sizes looks like:

    IMG_0256.jpg 2048 1536
    IMG_0256_lg.jpg 1200 900
    IMG_0256_med.jpg 800 600
    IMG_0256_thumb.jpg 200 150

    descrip looks like:

    100_2455   h   Driving down Miller Hill
    100_2549   v   Storage shed next to the red cabin

    This script Copyright © 2010, Christopher Swingley, 
    <cswingle@gmail.com> and licensed under the terms of the GNU
    General Public License v3.0.  Use at your own risk.
"""

import sys

if len(sys.argv) != 3:
    print "Error: Two arguments (image_sizes file, descrip file) required"
    print
    print usage
    sys.exit(1)

# Read all the image sizes
image_sizes = {}
with open(sys.argv[1]) as f:
    for line in f.readlines():
        (img, width, height) = line.split()
        (width, height) = map(int, (width, height))
        image_sizes[img] = (width, height)

data = []
with open(sys.argv[2]) as f:
    for line in f.readlines():
        line = line.strip()
        fields = line.split()
        image_base, orientation = fields[:2]
        descrip = ' '.join(fields[2:])
        data.append((image_base, orientation, descrip))

def build_link_string(i, size_str):
    if size_str == 'full':
        if i == 0:
            links = '||&nbsp;<a href="index.html">^^</a>&nbsp;<a href="%s.html">&gt;&gt;</a>' % (data[i+1][0])
        elif i == len(data) - 1:
            links = '<a href="%s.html">&lt;&lt;</a>&nbsp;<a href="index.html">^^</a>&nbsp;||' % (data[i-1][0])
        else:
            links = '<a href="%s.html">&lt;&lt;</a>&nbsp;<a href="index.html">^^</a>&nbsp;<a href="%s.html">&gt;&gt;</a>' % (data[i-1][0], data[i+1][0])
    else:
        if i == 0:
            links = '||&nbsp;<a href="index.html">^^</a>&nbsp;<a href="%s_%s.html">&gt;&gt;</a>' % (data[i+1][0], size_str)
        elif i == len(data) - 1:
            links = '<a href="%s_%s.html">&lt;&lt;</a>&nbsp;<a href="index.html">^^</a>&nbsp;||' % (data[i-1][0], size_str)
        else:
            links = '<a href="%s_%s.html">&lt;&lt;</a>&nbsp;<a href="index.html">^^</a>&nbsp;<a href="%s_%s.html">&gt;&gt;</a>' % (data[i-1][0], size_str, data[i+1][0], size_str)
    return links

def build_image_string(image_base, orientation, size_str):
    if size_str == 'full':
        image_size_str = 'width="%s" height="%s"' % (image_sizes["%s.jpg" % (image_base)])
        image_string = '<img src="%s.jpg" %s>' % (image_base, image_size_str)
    else:
        image_size_str = 'width="%s" height="%s"' % (image_sizes["%s_%s.jpg" % (image_base, size_str)])
        image_string = '<img src="%s_%s.jpg" %s>' % (image_base, size_str, image_size_str)
    return image_string

for i in range(len(data)):
# for i in range(2):
    html_header_string = '<meta charset="utf-8" />\n<link rel="author" href="mailto:cswingle@gmail.com">\n<!--[if lt IE 9]>\n<script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>\n<![endif]-->\n<link rel="stylesheet" href="plain.css" title="Swingley Stylesheet" />\n<link rel="shortcut icon" href="favicon.ico" />\n<link rel="license" href="http://creativecommons.org/licenses/by-sa/3.0/legalcode" />\n<title>Cabin renovation, Summer 2010</title>'
    (image_base, orientation, descrip) = data[i]
    print "Making %s_med.html" % (image_base)
    ofl = open("%s_med.html" % (image_base), 'w')
    links = build_link_string(i, "med")
    image_string = build_image_string(image_base, orientation, "med")
    ofl.write('<!DOCTYPE html><html lang="en"><head>%s</head><body><h3>%s</h3><p style="text-align: center;">%s<br />%s<br />%s</p></body></html>' % (html_header_string, descrip, links, image_string, links))
    ofl.close()
    print "Making %s_lg.html" % (image_base)
    ofl = open("%s_lg.html" % (image_base), 'w')
    links = build_link_string(i, "lg")
    image_string = build_image_string(image_base, orientation, "lg")
    ofl.write('<!DOCTYPE html><html lang="en"><head>%s</head><body><h3>%s</h3><p style="text-align: center;">%s<br />%s<br />%s</p></body></html>' % (html_header_string, descrip, links, image_string, links))
    ofl.close()
    print "Making %s.html" % (image_base)
    ofl = open("%s.html" % (image_base), 'w')
    links = build_link_string(i, "full")
    image_string = build_image_string(image_base, orientation, "full")
    ofl.write('<!DOCTYPE html><html lang="en"><head>%s</head><body><h3>%s</h3><p style="text-align: center;">%s<br />%s<br />%s</p></body></html>' % (html_header_string, descrip, links, image_string, links))
    ofl.close()
